@@ -23,14 +23,17 @@
 import logging
 import traceback
 import requests
-import cStringIO
-from urlparse import urlparse
+from io import BytesIO
+try:
+    from urllib.parse import urlparse
+except ImportError:
+    from urlparse import urlparse
 
 from Ice import Exception as IceException
 from omero import ApiUsageException, ServerError
 
 from django.conf import settings
-from mapr_settings import mapr_settings
+from .mapr_settings import mapr_settings
 
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseServerError, HttpResponseBadRequest
@@ -46,9 +49,17 @@ from django_redis import get_redis_connection
 
 from omero.gateway.utils import toBoolean
 
-from show import mapr_paths_to_object
-from show import MapShow as Show
-import tree as mapr_tree
+from .show import mapr_paths_to_object
+from .show import MapShow as Show
+from .tree import count_mapannotations, \
+                  marshal_mapannotations, \
+                  marshal_screens, \
+                  marshal_projects, \
+                  marshal_datasets, \
+                  marshal_plates, \
+                  marshal_images, \
+                  load_mapannotation, \
+                  marshal_autocomplete
 
 from omeroweb.webclient.decorators import login_required, render_response
 from omeroweb.webclient.views import get_long_or_default, get_bool_or_default
@@ -59,7 +70,12 @@ from omeroweb.webclient.views import _load_template as _webclient_load_template
 from omeroweb.webclient.views import api_paths_to_object \
     as webclient_api_paths_to_object
 
-from omeroweb.http import HttpJPEGResponse
+try:
+    # renamed for Django 1.11
+    from omeroweb.httprsp import HttpJPEGResponse
+except ImportError:
+    # old name for backwards compatibility
+    from omeroweb.http import HttpJPEGResponse
 
 import omeroweb
 
@@ -103,7 +119,7 @@ def get_unicode_or_default(request, name, default):
     val = None
     val_raw = request.GET.get(name, default)
     if val_raw is not None:
-        val = unicode(strip_tags(val_raw))
+        val = strip_tags(val_raw)
     return val
 
 
@@ -183,7 +199,7 @@ def index(request, menu, conn=None, url=None, **kwargs):
     kwargs['template'] = "mapr/base_mapr.html"
     context = _webclient_load_template(request, menu,
                                        conn=conn, url=url, **kwargs)
-    context['active_user'] = context['active_user'] or {'id': -1}
+    context['active_user'] = context.get('active_user', {'id': -1})
     context['mapr_conf'] = {
         'menu': menu,
         'menu_all': mapr_settings.CONFIG[menu]['all'],
@@ -197,6 +213,11 @@ def index(request, menu, conn=None, url=None, **kwargs):
     return context
 
 
+def api_mapr_config(request):
+    """Return mapr_settings.CONFIG as JSON."""
+    return JsonResponse(mapr_settings.CONFIG)
+
+
 @login_required()
 def api_paths_to_object(request, menu=None, conn=None, **kwargs):
     """
@@ -281,7 +302,7 @@ def api_experimenter_list(request, menu, conn=None, **kwargs):
                 experimenter['extra']['query'] = query
 
             # count children
-            experimenter['childCount'] = mapr_tree.count_mapannotations(
+            experimenter['childCount'] = count_mapannotations(
                 conn=conn,
                 mapann_value=mapann_value,
                 query=query,
@@ -337,7 +358,7 @@ def api_mapannotation_list(request, menu, conn=None, **kwargs):
             # Get attributes from map annotation
             if orphaned:
                 # offset = _get_wildcard_limit(mapr_settings, menu)
-                mapannotations = mapr_tree.marshal_mapannotations(
+                mapannotations = marshal_mapannotations(
                     conn=conn,
                     mapann_value=mapann_value,
                     query=query,
@@ -349,7 +370,7 @@ def api_mapannotation_list(request, menu, conn=None, **kwargs):
                     page=page,
                     limit=limit)
             else:
-                screens = mapr_tree.marshal_screens(
+                screens = marshal_screens(
                     conn=conn,
                     mapann_value=mapann_value,
                     query=query,
@@ -359,7 +380,7 @@ def api_mapannotation_list(request, menu, conn=None, **kwargs):
                     experimenter_id=experimenter_id,
                     page=page,
                     limit=limit)
-                projects = mapr_tree.marshal_projects(
+                projects = marshal_projects(
                     conn=conn,
                     mapann_value=mapann_value,
                     query=query,
@@ -404,7 +425,7 @@ def api_datasets_list(request, menu, conn=None, **kwargs):
     try:
         if _get_wildcard(mapr_settings, menu) or mapann_value:
             # Get the images
-            datasets = mapr_tree.marshal_datasets(
+            datasets = marshal_datasets(
                 conn=conn,
                 project_id=project_id,
                 mapann_value=mapann_value,
@@ -448,7 +469,7 @@ def api_plate_list(request, menu, conn=None, **kwargs):
     try:
         if _get_wildcard(mapr_settings, menu) or mapann_value:
             # Get the images
-            plates = mapr_tree.marshal_plates(
+            plates = marshal_plates(
                 conn=conn,
                 screen_id=screen_id,
                 mapann_value=mapann_value,
@@ -496,7 +517,7 @@ def api_image_list(request, menu, conn=None, **kwargs):
     try:
         if _get_wildcard(mapr_settings, menu) or mapann_value:
             # Get the images
-            images = mapr_tree.marshal_images(
+            images = marshal_images(
                 conn=conn,
                 parent=parent,
                 parent_id=parent_id,
@@ -564,7 +585,7 @@ def api_annotations(request, menu, conn=None, **kwargs):
     anns = []
     exps = []
     try:
-        anns, exps = mapr_tree.load_mapannotation(
+        anns, exps = load_mapannotation(
             conn=conn,
             mapann_ns=mapann_ns,
             mapann_names=mapann_names,
@@ -604,7 +625,7 @@ def mapannotations_autocomplete(request, menu, conn=None, **kwargs):
     autocomplete = []
     try:
         if mapann_value:
-            autocomplete = mapr_tree.marshal_autocomplete(
+            autocomplete = marshal_autocomplete(
                 conn=conn,
                 mapann_value=mapann_value,
                 query=query,
@@ -656,7 +677,7 @@ def mapannotations_favicon(request, conn=None, **kwargs):
 
     with Image.open(mapr_settings.DEFAULT_FAVICON) as img:
         img.thumbnail((16, 16), Image.ANTIALIAS)
-        f = cStringIO.StringIO()
+        f = BytesIO()
         img.save(f, "PNG")
         f.seek(0)
         return HttpJPEGResponse(f.read())
